@@ -30,6 +30,7 @@ class Interpreter(ABC):
 
         self.mapped_labels = metadata.get("mapped_labels")
         self.label_probabilities = metadata.get("label_probabilities")
+        self.thresholds = metadata.get("thresholds")
         self.preprocess_fn = self.get_preprocess_fn()
 
     @abstractmethod
@@ -169,9 +170,8 @@ class Interpreter(ABC):
 
     def frames_for_prediction(self, clip, track, **args):
         frames_per_classify = args.get("frames_per_classify", 25)
-
+        max_predictions = args.get("num_predictions")
         if frames_per_classify > 1:
-            max_segments = args.get("max_segments", None)
             predict_from_last = args.get("predict_from_last", None)
             segment_frames = args.get("segment_frames", None)
             dont_filter = args.get("dont_filter", False)
@@ -227,14 +227,14 @@ class Interpreter(ABC):
                 segment_frames=segment_frames,
                 segment_types=self.params.segment_types,
                 from_last=predict_from_last,
-                max_segments=max_segments,
+                max_segments=max_predictions,
                 dont_filter=dont_filter,
                 filter_by_fp=False,
                 min_segments=args.get("min_segments"),
             )
             return segments
         else:
-            max_frames = args.get("max_segments", None)
+            max_frames = max_predictions
             frames = [
                 region
                 for region in track.bounds_history
@@ -531,7 +531,7 @@ def get_interpreter(model, run_over_network=False):
     # model_name, type = os.path.splitext(model.model_file)
 
     logging.info(
-        "Loading %s of type %s over netowrk?? %s",
+        "Loading %s of type %s over network: %s",
         model.model_file,
         model.type,
         model.run_over_network,
@@ -548,9 +548,9 @@ def get_interpreter(model, run_over_network=False):
     else:
         from ml_tools.kerasmodel import KerasModel
 
+        print("Run over netowrk", run_over_network)
         classifier = KerasModel(run_over_network=run_over_network)
-        if not run_over_network:
-            classifier.load_model(model.model_file, weights=model.model_weights)
+        classifier.load_model(model.model_file, weights=model.model_weights)
     classifier.id = model.id
     classifier.port = model.port
     return classifier
