@@ -354,7 +354,9 @@ class PiClassifier(Processor):
             self.max_keep_frames = (
                 self.frames_per_classify * 2 if not preview_type else None
             )
-            self.predictions[model.id] = Predictions(self.classifier.labels, model)
+            self.predictions[model.id] = Predictions(
+                self.classifier.labels, model, self.classifier.thresholds
+            )
             self.num_labels = len(self.classifier.labels)
             logging.info("Labels are %s ", self.classifier.labels)
             global predictions
@@ -368,7 +370,7 @@ class PiClassifier(Processor):
             global fp_model
             fp_model = self.fp_model
             self.predictions[self.fp_model.id] = Predictions(
-                self.fp_model.labels, fp_config
+                self.fp_model.labels, fp_config, self.classifier.thresholds
             )
 
     def new_clip(self, preview_frames):
