@@ -1021,7 +1021,7 @@ class Track:
                 prediction = predictions.prediction_for(self.get_id())
                 if prediction is None:
                     continue
-                prediciont_meta = prediction.get_metadata()
+                prediciont_meta = prediction.get_metadata(predictions.thresholds)
                 prediciont_meta["model_id"] = model_id
                 prediction_info.append(prediciont_meta)
         track_info["predictions"] = prediction_info
